@@ -25,6 +25,38 @@
 
 namespace swoole {
 
+std::string Logger::get_pretty_name(const std::string &pretty_function, bool strip) {
+    size_t brackets = pretty_function.find_first_of("(");
+    if (brackets == pretty_function.npos) {
+        return "";
+    }
+
+    size_t begin = pretty_function.substr(0, brackets).rfind(" ") + 1;
+    size_t end = brackets - begin;
+    if (!strip) {
+        return pretty_function.substr(begin, end);
+    }
+
+    auto method_name = pretty_function.substr(begin, end);
+    size_t count = 0, index = method_name.length();
+    while (true) {
+        index = method_name.rfind("::", index);
+        if (index == method_name.npos) {
+            if (count == 1) {
+                return method_name.substr(method_name.rfind("::") + 2);
+            }
+            break;
+        }
+        count++;
+        if (count == 2) {
+            return method_name.substr(index + 2);
+        }
+        index -= 2;
+    }
+
+    return method_name;
+}
+
 bool Logger::open(const char *_log_file) {
     if (opened) {
         close();
@@ -84,33 +116,33 @@ void Logger::set_rotation(int _rotation) {
 bool Logger::redirect_stdout_and_stderr(int enable) {
     if (enable) {
         if (!opened) {
-            swWarn("no log file opened");
+            swoole_warning("no log file opened");
             return false;
         }
         if (redirected) {
-            swWarn("has been redirected");
+            swoole_warning("has been redirected");
             return false;
         }
         if ((stdout_fd = dup(STDOUT_FILENO)) < 0) {
-            swSysWarn("dup(STDOUT_FILENO) failed");
+            swoole_sys_warning("dup(STDOUT_FILENO) failed");
             return false;
         }
         if ((stderr_fd = dup(STDERR_FILENO)) < 0) {
-            swSysWarn("dup(STDERR_FILENO) failed");
+            swoole_sys_warning("dup(STDERR_FILENO) failed");
             return false;
         }
         swoole_redirect_stdout(log_fd);
         redirected = true;
     } else {
         if (!redirected) {
-            swWarn("no redirected");
+            swoole_warning("no redirected");
             return false;
         }
         if (dup2(stdout_fd, STDOUT_FILENO) < 0) {
-            swSysWarn("dup2(STDOUT_FILENO) failed");
+            swoole_sys_warning("dup2(STDOUT_FILENO) failed");
         }
         if (dup2(stderr_fd, STDERR_FILENO) < 0) {
-            swSysWarn("dup2(STDERR_FILENO) failed");
+            swoole_sys_warning("dup2(STDERR_FILENO) failed");
         }
         ::close(stdout_fd);
         ::close(stderr_fd);
@@ -256,8 +288,8 @@ void Logger::put(int level, const char *content, size_t length) {
 
     if (date_with_microseconds) {
         auto now_us = std::chrono::duration_cast<std::chrono::microseconds>(now.time_since_epoch()).count();
-        l_data_str +=
-            sw_snprintf(date_str + l_data_str, SW_LOG_DATE_STRLEN - l_data_str, "<.%lld>", (long long) now_us - now_sec * 1000000);
+        l_data_str += sw_snprintf(
+            date_str + l_data_str, SW_LOG_DATE_STRLEN - l_data_str, "<.%lld>", (long long) now_us - now_sec * 1000000);
     }
 
     char process_flag = '@';
