@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2018 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -24,6 +24,13 @@ using swoole::Coroutine;
 using swoole::PHPCoroutine;
 using swoole::coroutine::Socket;
 
+#if HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+#if HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 static int le_proc_open;
 static const char *le_proc_name = "process/coroutine";
 
@@ -34,7 +41,7 @@ static proc_co_env_t _php_array_to_envp(zval *environment) {
     zend_string *key, *str;
     char **ep;
     char *p;
-    size_t cnt, l, sizeenv = 0;
+    size_t cnt, sizeenv = 0;
     HashTable *env_hash;
 
     memset(&env, 0, sizeof(env));
@@ -77,26 +84,22 @@ static proc_co_env_t _php_array_to_envp(zval *environment) {
     ep = env.envarray = (char **) ecalloc(cnt + 1, sizeof(char *));
     p = env.envp = (char *) ecalloc(sizeenv + 4, 1);
 
-    void *_v1, *_v2;
-    ZEND_HASH_FOREACH_STR_KEY_PTR(env_hash, _v1, _v2) {
-        key = (zend_string *) _v1;
-        str = (zend_string *) _v2;
+    void *v1, *v2;
+    ZEND_HASH_FOREACH_STR_KEY_PTR(env_hash, v1, v2) {
+        key = (zend_string *) v1;
+        str = (zend_string *) v2;
+        *ep = p;
+        ++ep;
 
         if (key) {
-            l = ZSTR_LEN(key) + ZSTR_LEN(str) + 2;
             memcpy(p, ZSTR_VAL(key), ZSTR_LEN(key));
-            strcat(p, "=");
-            strncat(p, ZSTR_VAL(str), ZSTR_LEN(str));
-
-            *ep = p;
-            ++ep;
-            p += l;
-        } else {
-            memcpy(p, ZSTR_VAL(str), ZSTR_LEN(str));
-            *ep = p;
-            ++ep;
-            p += ZSTR_LEN(str) + 1;
+            p += ZSTR_LEN(key);
+            *p++ = '=';
         }
+
+        memcpy(p, ZSTR_VAL(str), ZSTR_LEN(str));
+        p += ZSTR_LEN(str);
+        *p++ = '\0';
         zend_string_release(str);
     }
     ZEND_HASH_FOREACH_END();
@@ -111,12 +114,12 @@ static proc_co_env_t _php_array_to_envp(zval *environment) {
 /* }}} */
 
 /* {{{ _php_free_envp */
-static void _php_free_envp(proc_co_env_t env) {
+static void _php_free_envp(proc_co_env_t env, int is_persistent) {
     if (env.envarray) {
-        efree(env.envarray);
+        pefree(env.envarray, is_persistent);
     }
     if (env.envp) {
-        efree(env.envp);
+        pefree(env.envp, is_persistent);
     }
 }
 /* }}} */
@@ -144,7 +147,7 @@ static void proc_co_rsrc_dtor(zend_resource *rsrc) {
         *proc->wstatus = wstatus;
     }
 
-    _php_free_envp(proc->env);
+    _php_free_envp(proc->env, proc->is_persistent);
     efree(proc->pipes);
     efree(proc->command);
     efree(proc);
@@ -249,6 +252,7 @@ PHP_FUNCTION(swoole_proc_get_status) {
 
 #define DESC_PIPE 1
 #define DESC_FILE 2
+#define DESC_REDIRECT 3
 #define DESC_PARENT_MODE_WRITE 8
 
 struct php_proc_open_descriptor_item {
@@ -259,11 +263,27 @@ struct php_proc_open_descriptor_item {
 };
 /* }}} */
 
-/* {{{ proto resource proc_open(string command, array descriptorspec, array &pipes [, string cwd [, array env [, array
-   other_options]]]) Run a process with more control over it's file descriptors */
+static zend_string *get_valid_arg_string(zval *zv, int elem_num) {
+    zend_string *str = zval_get_string(zv);
+    if (!str) {
+        return NULL;
+    }
+
+    if (strlen(ZSTR_VAL(str)) != ZSTR_LEN(str)) {
+        php_error_docref(NULL, E_WARNING, "Command array element %d contains a null byte", elem_num);
+        zend_string_release(str);
+        return NULL;
+    }
+
+    return str;
+}
+
+/* {{{ proto resource proc_open(string|array command, array descriptorspec, array &pipes [, string cwd [, array env [,
+   array other_options]]]) Run a process with more control over it's file descriptors */
 PHP_FUNCTION(swoole_proc_open) {
-    char *command, *cwd = NULL;
-    size_t command_len, cwd_len = 0;
+    zval *command_zv;
+    char *command = NULL, *cwd = NULL;
+    size_t cwd_len = 0;
     zval *descriptorspec;
     zval *pipes;
     zval *environment = NULL;
@@ -277,11 +297,14 @@ PHP_FUNCTION(swoole_proc_open) {
     struct php_proc_open_descriptor_item *descriptors = NULL;
     int ndescriptors_array;
 
+    char **argv = NULL;
+
     pid_t child;
     proc_co_t *proc;
+    int is_persistent = 0; /* TODO: ensure that persistent procs will work */
 
     ZEND_PARSE_PARAMETERS_START(3, 6)
-    Z_PARAM_STRING(command, command_len)
+    Z_PARAM_ZVAL(command_zv)
     Z_PARAM_ARRAY(descriptorspec)
 #if PHP_VERSION_ID >= 70400
     Z_PARAM_ZVAL(pipes)
@@ -294,6 +317,42 @@ PHP_FUNCTION(swoole_proc_open) {
     Z_PARAM_ARRAY_EX(other_options, 1, 0)
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
+    memset(&env, 0, sizeof(env));
+
+    if (Z_TYPE_P(command_zv) == IS_ARRAY) {
+        zval *arg_zv;
+        uint32_t num_elems = zend_hash_num_elements(Z_ARRVAL_P(command_zv));
+        if (num_elems == 0) {
+            php_error_docref(NULL, E_WARNING, "Command array must have at least one element");
+            RETURN_FALSE;
+        }
+
+        argv = (char **) safe_emalloc(sizeof(char *), num_elems + 1, 0);
+        i = 0;
+        ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(command_zv), arg_zv) {
+            zend_string *arg_str = get_valid_arg_string(arg_zv, i + 1);
+            if (!arg_str) {
+                argv[i] = NULL;
+                goto exit_fail;
+            }
+
+            if (i == 0) {
+                command = pestrdup(ZSTR_VAL(arg_str), is_persistent);
+            }
+
+            argv[i++] = estrdup(ZSTR_VAL(arg_str));
+            zend_string_release(arg_str);
+        }
+        ZEND_HASH_FOREACH_END();
+        argv[i] = NULL;
+
+        /* As the array is non-empty, we should have found a command. */
+        ZEND_ASSERT(command);
+    } else {
+        convert_to_string(command_zv);
+        command = pestrdup(Z_STRVAL_P(command_zv), is_persistent);
+    }
+
     php_swoole_check_reactor();
     if (php_swoole_signal_isset_handler(SIGCHLD)) {
         php_swoole_error(E_WARNING, "The signal [SIGCHLD] is registered, cannot execute swoole_proc_open");
@@ -302,10 +361,6 @@ PHP_FUNCTION(swoole_proc_open) {
 
     Coroutine::get_current_safe();
 
-    command = estrdup(command);
-
-    command_len = strlen(command);
-
     if (environment) {
         env = _php_array_to_envp(environment);
     } else {
@@ -364,7 +419,7 @@ PHP_FUNCTION(swoole_proc_open) {
             }
 
             if (strcmp(Z_STRVAL_P(ztype), "pipe") == 0) {
-                int newpipe[2];
+                php_file_descriptor_t newpipe[2];
                 zval *zmode;
 
                 if ((zmode = zend_hash_index_find(Z_ARRVAL_P(descitem), 1)) != NULL) {
@@ -399,14 +454,26 @@ PHP_FUNCTION(swoole_proc_open) {
                 descriptors[ndesc].mode = DESC_FILE;
 
                 if ((zfile = zend_hash_index_find(Z_ARRVAL_P(descitem), 1)) != NULL) {
+#if PHP_VERSION_ID >= 70400
+                    if (!try_convert_to_string(zfile)) {
+                        goto exit_fail;
+                    }
+#else
                     convert_to_string_ex(zfile);
+#endif
                 } else {
                     php_swoole_fatal_error(E_WARNING, "Missing file name parameter for 'file'");
                     goto exit_fail;
                 }
 
                 if ((zmode = zend_hash_index_find(Z_ARRVAL_P(descitem), 2)) != NULL) {
+#if PHP_VERSION_ID >= 70400
+                    if (!try_convert_to_string(zmode)) {
+                        goto exit_fail;
+                    }
+#else
                     convert_to_string_ex(zmode);
+#endif
                 } else {
                     php_swoole_fatal_error(E_WARNING, "Missing mode parameter for 'file'");
                     goto exit_fail;
@@ -424,6 +491,94 @@ PHP_FUNCTION(swoole_proc_open) {
                 }
 
                 descriptors[ndesc].childend = fd;
+            } else if (strcmp(Z_STRVAL_P(ztype), "redirect") == 0) {
+                zval *ztarget = zend_hash_index_find_deref(Z_ARRVAL_P(descitem), 1);
+                struct php_proc_open_descriptor_item *target = NULL;
+                php_file_descriptor_t childend;
+
+                if (!ztarget) {
+                    php_error_docref(NULL, E_WARNING, "Missing redirection target");
+                    goto exit_fail;
+                }
+                if (Z_TYPE_P(ztarget) != IS_LONG) {
+                    php_error_docref(NULL, E_WARNING, "Redirection target must be an integer");
+                    goto exit_fail;
+                }
+
+                for (i = 0; i < ndesc; i++) {
+                    if (descriptors[i].index == Z_LVAL_P(ztarget)) {
+                        target = &descriptors[i];
+                        break;
+                    }
+                }
+                if (target) {
+                    childend = target->childend;
+                } else {
+                    if (Z_LVAL_P(ztarget) < 0 || Z_LVAL_P(ztarget) > 2) {
+                        php_error_docref(
+                            NULL, E_WARNING, "Redirection target " ZEND_LONG_FMT " not found", Z_LVAL_P(ztarget));
+                        goto exit_fail;
+                    }
+
+                    /* Support referring to a stdin/stdout/stderr pipe adopted from the parent,
+                     * which happens whenever an explicit override is not provided. */
+#ifndef PHP_WIN32
+                    childend = Z_LVAL_P(ztarget);
+#else
+                    switch (Z_LVAL_P(ztarget)) {
+                    case 0:
+                        childend = GetStdHandle(STD_INPUT_HANDLE);
+                        break;
+                    case 1:
+                        childend = GetStdHandle(STD_OUTPUT_HANDLE);
+                        break;
+                    case 2:
+                        childend = GetStdHandle(STD_ERROR_HANDLE);
+                        break;
+                        EMPTY_SWITCH_DEFAULT_CASE()
+                    }
+#endif
+                }
+
+#ifdef PHP_WIN32
+                descriptors[ndesc].childend = dup_handle(childend, TRUE, FALSE);
+                if (descriptors[ndesc].childend == NULL) {
+                    php_error_docref(NULL, E_WARNING, "Failed to dup() for descriptor " ZEND_LONG_FMT, nindex);
+                    goto exit_fail;
+                }
+#else
+                descriptors[ndesc].childend = dup(childend);
+                if (descriptors[ndesc].childend < 0) {
+                    php_error_docref(NULL,
+                                     E_WARNING,
+                                     "Failed to dup() for descriptor " ZEND_LONG_FMT " - %s",
+                                     nindex,
+                                     strerror(errno));
+                    goto exit_fail;
+                }
+#endif
+                descriptors[ndesc].mode = DESC_REDIRECT;
+            } else if (strcmp(Z_STRVAL_P(ztype), "null") == 0) {
+#ifndef PHP_WIN32
+                descriptors[ndesc].childend = open("/dev/null", O_RDWR);
+                if (descriptors[ndesc].childend < 0) {
+                    php_error_docref(NULL, E_WARNING, "Failed to open /dev/null - %s", strerror(errno));
+                    goto exit_fail;
+                }
+#else
+                descriptors[ndesc].childend = CreateFileA("nul",
+                                                          GENERIC_READ | GENERIC_WRITE,
+                                                          FILE_SHARE_READ | FILE_SHARE_WRITE,
+                                                          NULL,
+                                                          OPEN_EXISTING,
+                                                          0,
+                                                          NULL);
+                if (descriptors[ndesc].childend == NULL) {
+                    php_error_docref(NULL, E_WARNING, "Failed to open nul");
+                    goto exit_fail;
+                }
+#endif
+                descriptors[ndesc].mode = DESC_FILE;
             } else if (strcmp(Z_STRVAL_P(ztype), "pty") == 0) {
                 php_swoole_fatal_error(E_WARNING, "pty pseudo terminal not supported on this system");
                 goto exit_fail;
@@ -463,10 +618,18 @@ PHP_FUNCTION(swoole_proc_open) {
             php_ignore_value(chdir(cwd));
         }
 
-        if (env.envarray) {
-            execle("/bin/sh", "sh", "-c", command, NULL, env.envarray);
+        if (argv) {
+            /* execvpe() is non-portable, use environ instead. */
+            if (env.envarray) {
+                environ = env.envarray;
+            }
+            execvp(command, argv);
         } else {
-            execl("/bin/sh", "sh", "-c", command, NULL);
+            if (env.envarray) {
+                execle("/bin/sh", "sh", "-c", command, NULL, env.envarray);
+            } else {
+                execl("/bin/sh", "sh", "-c", command, NULL);
+            }
         }
         _exit(127);
 
@@ -488,15 +651,6 @@ PHP_FUNCTION(swoole_proc_open) {
 
     /* we forked/spawned and this is the parent */
 
-    proc = (proc_co_t *) emalloc(sizeof(proc_co_t));
-    proc->wstatus = nullptr;
-    proc->command = command;
-    proc->pipes = (zend_resource **) emalloc(sizeof(zend_resource *) * ndesc);
-    proc->npipes = ndesc;
-    proc->child = child;
-    proc->env = env;
-    proc->running = true;
-
 #if PHP_VERSION_ID >= 70400
     pipes = zend_try_array_init(pipes);
     if (!pipes) {
@@ -507,6 +661,16 @@ PHP_FUNCTION(swoole_proc_open) {
     array_init(pipes);
 #endif
 
+    proc = (proc_co_t *) pemalloc(sizeof(proc_co_t), is_persistent);
+    proc->is_persistent = is_persistent;
+    proc->wstatus = nullptr;
+    proc->running = true;
+    proc->command = command;
+    proc->pipes = (zend_resource **) emalloc(sizeof(zend_resource *) * ndesc);
+    proc->npipes = ndesc;
+    proc->child = child;
+    proc->env = env;
+
     /* clean up all the child ends and then open streams on the parent
      * ends, where appropriate */
     for (i = 0; i < ndesc; i++) {
@@ -537,15 +701,35 @@ PHP_FUNCTION(swoole_proc_open) {
         }
     }
 
+    if (argv) {
+        char **arg = argv;
+        while (*arg != NULL) {
+            efree(*arg);
+            arg++;
+        }
+        efree(argv);
+    }
+
     efree(descriptors);
     ZVAL_RES(return_value, zend_register_resource(proc, le_proc_open));
     return;
 
 exit_fail:
-    efree(descriptors);
-    _php_free_envp(env);
-    efree(command);
-
+    if (descriptors) {
+        efree(descriptors);
+    }
+    _php_free_envp(env, is_persistent);
+    if (command) {
+        pefree(command, is_persistent);
+    }
+    if (argv) {
+        char **arg = argv;
+        while (*arg != NULL) {
+            efree(*arg);
+            arg++;
+        }
+        efree(argv);
+    }
     RETURN_FALSE;
 }
 /* }}} */
